@@ -26,8 +26,16 @@ impl Client {
     ];
     pub async fn new(project_id: &str) -> Result<Self, Error> {
         if let Ok(host) = std::env::var("PUBSUB_EMULATOR_HOST") {
-            DOMAIN_NAME.set(host.clone()).unwrap();
-            ENDPOINT.set(format!("http://{}", host)).unwrap();
+            let (domain, port) = host.split_once(":").unwrap();
+            DOMAIN_NAME.set(String::from(domain)).unwrap();
+            ENDPOINT.set(format!("http://{}:{}", host, port)).unwrap();
+        } else {
+            DOMAIN_NAME
+                .set(String::from("pubsub.googleapis.com"))
+                .unwrap();
+            ENDPOINT
+                .set(String::from("https://pubsub.googleapis.com"))
+                .unwrap();
         }
         let pem = get_pem();
         let tls_config = ClientTlsConfig::new()
